@@ -7,7 +7,7 @@
 ##======================================================================
 
 package DDC::Client;
-use DDC::Utils qw(escape);
+use DDC::Utils qw(:escape);
 use DDC::HitList;
 use DDC::Hit;
 use IO::Handle;
