@@ -86,7 +86,7 @@ sub toString {
   }
   elsif ($hits->{hits_} && @{$hits->{hits_}}) {
     ##-- usual case: retrieve hit strings
-    my $useMatchIds = $fmt->{useMatchIds} // (grep {$_>0 && $_!=1} map {$_->{hl_}} map {@{$_->{ctx_}[1]}} @{$hits->{hits_}});
+    my $useMatchIds = defined($fmt->{useMatchIds}) ? $fmt->{useMatchIds} : (grep {$_>0 && $_!=1} map {$_->{hl_}} map {@{$_->{ctx_}[1]}} @{$hits->{hits_}});
     return join("\n",
 		map {
 		  $fmt->hitString($hits->{hits_}[$_], $hits->{defaultField}, $_+$hits->{start}, $useMatchIds)
